@@ -23,7 +23,7 @@ void ci_mh_atet(double *result,int * num_p_mz, int * num_p_dz, int * num_col_a,
 	double *var_b_a, double *var_b_e, int *D_a, int *D_e, int *iter_n, int *burn, double *sd_mcmc);
 */
 void ci_mh_atctet(double *result,int * num_p_mz, int * num_p_dz, int * num_col_a, int * num_col_c, int * num_col_e, 
-	double *ph_m, double *ph_d, double *B_des_a_m, double *B_des_a_d, double *B_des_c_m, double *B_des_c_d, double *B_des_e_m, double *B_des_e_d, double *G_a, double *G_c, double *G_e,
+	double *ph_m, double *ph_d, double *B_des_a_m, double *B_des_a_d, double *B_des_c_m, double *B_des_c_d, double *B_des_e_m, double *B_des_e_d, double *G_a, double *G_c, double *G_e, double *ei_a, double *ei_c, double *ei_e,
 	double *var_b_a, double *var_b_c, double *var_b_e, int *D_a, int *D_c, int *D_e, int *iter_n, int *burn, double *sd_mcmc);
 
 void ci_mh_atctet_2(double *result,int * num_p_mz, int * num_p_dz, int * num_col_a, int * num_col_c, int * num_col_e, 
